# <b> This is very simple package that comes with the following functionality:
- <b> 1. `multiplication_table()` : It prints the multiplication table from 1 to 5 by default
- <b> 2. `fahrenheit_to_celsius()` : It converts the fahrenheit to celsius by passing the one integer parameter to this function
- <b> 3. `celsius_to_fahrenheit()` : It converts the celsius to fahrenheit by passing the one integer parameter to this function
- <b> 4. `finds_the_longest_word()` : It returns the Longest Word by providing string as the first parameter
